import java.lang.Object;
/**
 * Eine Farm besteht aus einer rechteckigen, regelmäßigen, 
 * zweidimensionalen Anordnung einer bestimmten Anzahl 
 * an Weideflächen. Diese Weideflächen sind über 
 * Koordinaten (column/row) ansprechbar. Die Farm 
 * soll dafür eine rows * columns große Datenstruktur 
 * zum Speichern der Range-Objekte nutzen. Beachten 
 * Sie, dass Sie die gewählte Datenstruktur selber 
 * mit Range Objekten füllen müssen. 
 * 
 * (6 Punkte)
 * 
 */
public class Farm {

	private Range[][] farm;

	/**
	 * Initialisiert diese Farm mit der spezifizierten 
	 * Anzahl an Weideflächen. Die Farm besteht dann 
	 * insgesamt aus rows * columns Weideflächen. 
	 *
	 * @param rows die Höhe der Farm 
	 * @param columns die Breite der Farm 
	 */
	public Farm(int rows, int columns) { // constructor
	farm = new Range[rows][columns];
		for(int i=0; i<rows; i++){
			for(int j=0; j<columns; j++){
				this.farm[i][j] = new Range();
			}
		}
	}

	/**
	 * Gibt die Weidefläche an der entsprechenden Position 
	 * zurück. Sie können davon ausgehen, dass column 
	 * und row nur zulässige Werte haben. 
	 *
	 * @param row die Zeilennummer 
	 * @param column die Spaltennummer 
	 *
	 * @return die Weidefläche an der entsprechenden Position 
	 */
	public Range getRange(int row, int column) {
		return this.farm[row][column]; 
	}

	/**
	 * Gibt zurück wieviel Schafe sich im Durchschnitt 
	 * in der angegebenen Reihe befinden. Dies entspricht 
	 * der Summe der Schafe in der Reihe dividiert durch 
	 * die Anzahl an Weideflächen in der Reihe. 
	 *
	 * @param row die Zeilennummer 
	 *
	 * @return die durchschnittliche Anzahl an 
	 * 	Schafen in der angegebenen Reihe 
	 */
	public double averageSheepInRow(int row) {
		int sum = 0;
		int rangesum = 0;
		double avg = 0.0;
			
			for(int i=0; i<this.farm.length+1; i++){
				rangesum++;
				sum += this.farm[row][i].countSheep();
			}

		avg = (double)sum / (double)rangesum;
		
		return avg; 

	}

	/**
	 * Gibt zurück wieviel Schafe sich im Durchschnitt 
	 * in der angegebenen Spalte befinden. Dies entspricht 
	 * der Summe der Schafe in der Spalte dividiert 
	 * durch die Anzahl an Weideflächen in der Spalte. 
	 *
	 * @param column die Spaltennummer 
	 *
	 * @return die durchschnittliche Anzahl an 
	 * 	Schafen in der angegebenen Spalte 
	 */
	public double averageSheepInColumn(int column) {

		int sum = 0;
		int rangesum = 0;
		double avg = 0.0;
			
			for(int i=0; i<this.farm.length; i++){
				rangesum++;
				sum += this.farm[i][column].countSheep();
			}

		avg = (double)sum / (double)rangesum;
		
		return avg; 

	}

}